@@ -4,6 +4,7 @@ from typing import Optional, Callable, ClassVar, Literal, Dict, Union
 import logging
 import json
 from lxml import etree
+import time
 import os
 import requests
 
@@ -48,15 +49,18 @@ class Record(metaclass=abc.ABCMeta):
     parser: ClassVar[etree.XMLParser] = etree.XMLParser(remove_blank_text=True)
 
     @abc.abstractmethod
-    def __init__(self, zone: str,
+    def __init__(self,
+                 zone: str,
                  env: Literal['P', 'S'] = 'P',
                  data: Optional[Union['JsonData', 'XmlData']] = None) -> None:
         """Abstract constructor, all entities have at least a zone and an environment.
         """
         self.error = False
+        self.error_msg = None
         self.zone = zone
         self.env = env
         self.area = None
+        self.format = None
         self._data = data
 
     @abc.abstractmethod
@@ -64,6 +68,55 @@ class Record(metaclass=abc.ABCMeta):
         """Abstract method. This method is different according to the type of record"""
         return None
 
+    @staticmethod
+    def _api_call(method: Literal['get', 'put', 'post', 'delete'], *args, **kwargs) -> Optional[requests.Response]:
+        """Static method to handle http errors. Quit the program after 3 failed tries
+
+        :param method: 'get', 'put', 'post' or 'delete' according to the api method call
+        """
+
+        for api_try in [1, 2, 3]:
+            try:
+                if method == 'get':
+                    r = requests.get(*args, **kwargs)
+                elif method == 'put':
+                    r = requests.put(*args, **kwargs)
+                elif method == 'post':
+                    r = requests.post(*args, **kwargs)
+                elif method == 'delete':
+                    r = requests.delete(*args, **kwargs)
+                else:
+                    return None
+                return r
+
+            except requests.exceptions.RequestException as err:
+                logging.error(f'HTTP error: try {api_try} - message: {str(err)}')
+                if api_try == 300:
+                    logging.critical(f'HTTP error: try {api_try} => exiting of the program')
+                    exit()
+                time.sleep(3)
+
+    @staticmethod
+    def build_headers(data_format: Literal['json', 'xml'],
+                      zone: str,
+                      area: str,
+                      rights: Literal['R', 'RW'] = 'RW',
+                      env: Optional[Literal['P', 'S']] = 'P') -> Dict:
+        """
+        Build the headers for the API calls.
+        :param data_format: "json" or "xml"
+        :param zone: optional, if indicated allow to make the query in an other IZ
+        :param area: area of the record, bibs, users for example
+        :param rights: "R" for read only or "RW" for write and read rights
+        :param env: environment of the api call: 'P' for production, 'S' for sandbox
+        :return: dict with the headers
+        """
+
+        # Build header dict
+        return {'content-type': f'application/{data_format}',
+                'accept': f'application/{data_format}',
+                'Authorization': 'apikey ' + ApiKeys().get_key(zone, area, rights, env)}
+
     @property
     def data(self) -> Optional[Union[Dict, etree.Element]]:
         """Property that get xml data with API call. If not available, make an api call
@@ -129,13 +182,14 @@ class Record(metaclass=abc.ABCMeta):
         logging.info(f'{repr(self)}: record saved: {final_path}')
 
     def _get_headers(self,
-                     data_format: Literal['json', 'xml'] = 'json',
+                     data_format: Optional[Literal['json', 'xml']] = None,
                      zone: Optional[str] = None,
+                     area: Optional[str] = None,
                      rights: Literal['R', 'RW'] = 'RW',
                      env: Optional[Literal['P', 'S']] = None) -> Dict:
         """Build the headers for the API calls
 
-        :param data_format: "json" ou "xml" en fonction du format souhaité
+        :param data_format: "json" or "xml" according to the format of the record
         :param zone: optional, if indicated allow to make the query in another IZ
         que celle de l'objet courant
         :param env: environment of the api call: 'P' for production, 'S' for sandbox
@@ -143,15 +197,17 @@ class Record(metaclass=abc.ABCMeta):
         """
 
         # If values are not provided, fetch values of the current entity
+
         if zone is None:
             zone = self.zone
         if env is None:
             env = self.env
+        if area is None:
+            area = self.area
+        if data_format is None:
+            data_format = self.format
 
-        # Build header dict
-        return {'content-type': f'application/{data_format}',
-                'accept': f'application/{data_format}',
-                'Authorization': 'apikey ' + self.k.get_key(zone, self.area, rights, env)}
+        return self.build_headers(data_format, zone, area, rights, env)
 
     def _handle_error(self, r: requests.models.Response, msg: str):
         """Set the record error attribute to True and write the logs about the error
@@ -162,13 +218,20 @@ class Record(metaclass=abc.ABCMeta):
         """
         if 'json' in r.headers['Content-Type']:
             json_data = r.json()
-            error_message = json_data['errorList']['error'][0]['errorMessage']
+            try:
+                error_message = json_data['errorList']['error'][0]['errorMessage']
+            except KeyError:
+                error_message = 'unknown error'
         else:
-            xml = etree.fromstring(r.content, parser=self.parser)
-            error_message = xml.find('.//{http://com/exlibris/urm/general/xmlbeans}errorMessage').text
-        logging.error(f'{repr(self)} - {r.status_code}: '
+            try:
+                xml = etree.fromstring(r.content, parser=self.parser)
+                error_message = xml.find('.//{http://com/exlibris/urm/general/xmlbeans}errorMessage').text
+            except etree.XMLSyntaxError:
+                error_message = 'unknown error'
+        logging.error(f'{repr(self)} - {r.status_code if r is not None else "unknown"}: '
                       f'{msg} / {error_message}')
         self.error = True
+        self.error_msg = error_message
 
 
 class XmlData:
